@@ -27,19 +27,7 @@ con = console.Console()
 
 
 def topper():
-    fig = Figlet(font="speed")
-    rendered = fig.renderText("tgcf")
-    time_passed = 0
-
-    while time_passed < 5:
-        cmd = "clear" if os.name == "posix" else "cls"
-        os.system(cmd)
-        if time_passed % 2 == 0:
-            print(rendered)
-        else:
-            con.print(rendered)
-        time.sleep(0.5)
-        time_passed += 1
+    print("tgcf")
     version_check()
     print("\n")
 
